<?php
/**
 * WalkTheWeb
 * @package  WalkTheWeb
 */
 if (!defined('ABSPATH')) exit; // Exit if accessed directly
 
 /**
 * Main WalkTheWeb Class.
 * @class WalkTheWeb
 */
final class WalkTheWeb {
	
	public $version = '1.0.0';

	public $jsversion = '1.0.0';
	
	public $cssversion = '1.0.0';
	
	public $blogid = ''; 
	
	protected static $_instance = null;
	
	/**
	 * Main WalkTheWeb Instance.
	 * Ensures only one instance of WalkTheWeb is loaded or can be loaded.
	 * @return WalkTheWeb - Main instance.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}
	
	public function __construct() {
		$this->define_constants();
		$this->init_hooks();
		$this->init_options();
	}
	
	/**
	 * Define constant if not already set.
	 * @param string      $name  Constant name.
	 * @param string|bool $value Constant value.
	 */
	private function define( $name, $value ) {
		if (!defined( $name )) {
			define( $name, $value );
		}
	}
	
	/**
	 * Define WTW Constants.
	 */
	private function define_constants() {
		$this->define('WTW_ABSPATH', dirname( WTW_PLUGIN_FILE ).'/' );
		$this->define('WTW_PLUGIN_BASENAME', plugin_basename(WTW_PLUGIN_FILE) );
		$this->define('WTW_VERSION', $this->version );
		$this->define('WTW_PLUGIN_URL', WP_PLUGIN_URL.'/walktheweb');
	}
	
	/**
	 * action and filter hooks.
	 */
	private function init_hooks() {
		add_action('admin_menu', array( $this, 'walktheweb_menu'));
		add_action('wp_enqueue_scripts', array( $this, 'load_dashicons_front_end'));
		add_action('admin_enqueue_scripts', array( $this, 'walktheweb_enqueue_script'));
		add_action('init', array( $this, 'wtw_init'));
		add_action('init', array( $this, 'walktheweb_init_internal'));
		add_filter('query_vars', array( $this, 'walktheweb_image_query_vars'));
		add_filter('query_vars', array( $this, 'walktheweb_storeinfo_query_vars'));
		add_filter('query_vars', array( $this, 'walktheweb_confirmapi_query_vars'));
		add_action('parse_request', array( $this, 'walktheweb_parse_request'));
	}

	/**
	 * load admin/options js file.
	 */
	public function walktheweb_enqueue_script($hook) {
		wp_enqueue_script( 'wtw_main_js', plugin_dir_url( __FILE__ ).'wtw_main.js', array('jquery'), $this->jsversion, false);
		wp_enqueue_script( 'wtw_pageload_js', plugin_dir_url( __FILE__ ).'wtw_pageload.js', array('jquery'), $this->jsversion, true);
		wp_enqueue_style('wtw_style_css', plugin_dir_url( __FILE__ ).'wtw_style.css', array(), $this->cssversion, 'all');
	}
	
	/**
	 * Settings and Support links on plugin page.
	 */
	public function wtw_add_settings_link( $links ) {
		if (current_user_can('manage_options')) {
			$settings_link = '<a href="options.php?page=walktheweb_settings&tab=1">'.__( 'Settings' ).'</a>';
			$support_link = '<a href="options.php?page=walktheweb_settings&tab=8">'.__( 'Support' ).'</a>';
			$links = array_merge( array($settings_link,$support_link), $links );
		} else {
			$support_link = '<a href="https://www.walktheweb.com/knowledgebase_category/3d-stores/">'.__( 'Support' ).'</a>';
			$links = array_merge( array($support_link), $links );
		}
		return $links;
	}
	
	/**
	 * init WalkTheWeb when WordPress Initializes.
	 */
	public function wtw_init() {
		if (current_user_can('manage_options')) {
			add_action('admin_menu', array( $this, 'walktheweb_menu'));
		}
		add_filter("plugin_action_links_".WTW_PLUGIN_BASENAME, array($this, 'wtw_add_settings_link'));
	}
	
	/**
	 * init WalkTheWeb options and version check.
	 */
	private function init_options() {
		$this->blogid = get_current_blog_id();
		if (is_multisite()) {
			add_blog_option($this->blogid, 'walktheweb_version', $this->version, null, 'no');
			
			if (get_blog_option($this->blogid, 'walktheweb_version') != $this->version) {
				version_upgrade();
				update_blog_option($this->blogid, 'walktheweb_version', $this->version);
			}
		} else {
			add_option('walktheweb_version', $this->version);
			
			if (get_option('walktheweb_version') != $this->version) {
				version_upgrade();
				update_option('walktheweb_version', $this->version);
			}
		}
	}
	
	/**
	 * version upgrade for future versions.
	 */
	private function version_upgrade() {
		
	}
	
	/**
	 * WalkTheWeb Menu item.
	 */
	public function walktheweb_menu() {
		if (current_user_can('manage_options')) {
			add_menu_page('Walk the Web 3D Store', 'Walk the Web<sup>®</sup><br />3D Store', 'manage_options', 'walktheweb_settings', array($this,'walktheweb_settings_page'), 'dashicons-admin-site',56);
		}
	}
	
	/**
	 * WalkTheWeb Menu item icon.
	 */
	public function load_dashicons_front_end() {
		wp_enqueue_style('dashicons');
	}

	/**
	 * Rewrite Rules for API pages.
	 */
	public function walktheweb_init_internal() {
		add_rewrite_rule( 'image.php$', WTW_PLUGIN_URL.'/api/productimage.php?walktheweb_image_url=1', 'top' );
		add_rewrite_rule( 'storeinfo.php$', WTW_PLUGIN_URL.'/api/storeinfo.php?walktheweb_store_info=1', 'top' );
		add_rewrite_rule( 'confirmapi.php$', WTW_PLUGIN_URL.'/api/confirmapi.php?walktheweb_confirm_api=1', 'top' );
	}

	/**
	 * Query Var for image.php API pages.
	 */
	public function walktheweb_image_query_vars($query_vars) {
		$query_vars[] = 'walktheweb_image_url';
		return $query_vars;
	}

	/**
	 * Query Var for storeinfo.php API pages.
	 */
	public function walktheweb_storeinfo_query_vars($query_vars) {
		$query_vars[] = 'walktheweb_store_info';
		return $query_vars;
	}

	/**
	 * Query Var for confirmapi.php API pages.
	 */
	public function walktheweb_confirmapi_query_vars($query_vars) {
		$query_vars[] = 'walktheweb_confirm_api';
		return $query_vars;
	}
	
	/**
	 * Parse Request for API pages.
	 */
	public function walktheweb_parse_request( &$wp ) {
		if (array_key_exists( 'walktheweb_image_url', $wp->query_vars ) ) {
			include WTW_ABSPATH.'/api/productimage.php';
			exit();
		} elseif (array_key_exists('walktheweb_store_info', $wp->query_vars ) ) {
			include WTW_ABSPATH.'/api/storeinfo.php';
			exit();
		} elseif (array_key_exists('walktheweb_confirm_api', $wp->query_vars ) ) {
			include WTW_ABSPATH.'/api/confirmapi.php';
			exit();
		}
		return;
	}	
	
	/**
	 * Main Admin WalkTheWeb Form.
	 */
	public function walktheweb_settings_page() {
		if (!current_user_can('manage_options')) {
			wp_die(__("You don't have access to this page"));
		} else {
			$wtw_woocommerceisactive = '0';
			if ( is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
				$wtw_woocommerceisactive = '1';
			}
			$blogid = get_current_blog_id();
			$user = wp_get_current_user();
			$nonce = wp_create_nonce('wtw-updatesettings_'.$blogid);
			$noncecheck = '';
			if(isset($_GET['nonce']) && !empty($_GET['nonce'])) {
				$noncecheck = $_GET['nonce'];
			}
	?>
	<div class="wrap">
	<h2><span class="wtw_wtwBlue">Walk the Web<sup>®</sup></span> - 3D Store</h2>
	<form id="wtw_form" method="post" action="options.php?page=walktheweb_settings&tab=1&nonce=<?php echo $nonce; ?>">
	<?php
			$wtwuserid = '';
			$wtwuserid2 = '';
			$wtwlogin = '';
			$wtwapikey = '';
			$wtwapisecret = '';
			$wtw3duserid = '';
			$storename = esc_attr(get_bloginfo('name'));
			$wwwstoreurl = esc_url(get_bloginfo('wpurl'));
			$wwwstorecarturl = esc_url($wwwstoreurl."/cart/");
			$wwwstoreproducturl = esc_url($wwwstoreurl."/product/");
			$wwwstorewoocommerceapiurl = esc_url($wwwstoreurl."/wp-json/wc/v2/");
			$wpuserid = esc_attr($user->ID);
			$wplogin = esc_attr($user->user_login);
			$wpemail = esc_attr($user->user_email);
			$wpdisplayname = esc_attr($user->display_name);	
			$buildingid = '';
			$buildingname = esc_attr($user->user_login);
			$buildingsnapshotid = '';
			$communityid = '';
			$communityname = esc_attr($user->user_login);
			$communitysnapshotid = '';
			$woocommercekey = '';
			$woocommercesecret = '';
			$siteurlpart = esc_attr($user->user_login);
			$siteurl = esc_url('https://3d.walktheweb.com');
			$showstep = '1';
			$showwizard = '0';
			if (is_multisite()) {
				$storename = get_blog_option($blogid, 'walktheweb_storename', esc_attr(get_bloginfo('name')));
				$wtwuserid = get_blog_option($blogid, 'walktheweb_wtwuserid', '');
				$wtwuserid2 = get_blog_option($blogid, 'walktheweb_wtwuserid2', '');
				$wtwlogin = get_blog_option($blogid, 'walktheweb_wtwlogin', '');
				$wtwapikey = get_blog_option($blogid, 'walktheweb_wtwapikey', '');
				$wtwapisecret = get_blog_option($blogid, 'walktheweb_wtwapisecret', '');
				$wtw3duserid = get_blog_option($blogid, 'walktheweb_wtw3duserid', '');
				$wwwstoreurl = get_blog_option($blogid, 'walktheweb_wwwstoreurl', esc_url(get_bloginfo('wpurl')));
				$wwwstorecarturl = get_blog_option($blogid, 'walktheweb_wwwstorecarturl', esc_url($wwwstoreurl."/cart/"));
				$wwwstoreproducturl = get_blog_option($blogid, 'walktheweb_wwwstoreproducturl', esc_url($wwwstoreurl."/product/"));
				$wwwstorewoocommerceapiurl = get_blog_option($blogid, 'walktheweb_wwwstorewoocommerceapiurl', esc_url($wwwstoreurl."/wp-json/wc/v2/"));
				$wpuserid = get_blog_option($blogid, 'walktheweb_wpuserid', esc_attr($user->ID));
				$wplogin = get_blog_option($blogid, 'walktheweb_wplogin', esc_attr($user->user_login));
				$wpemail = get_blog_option($blogid, 'walktheweb_wpemail', esc_attr($user->user_email));
				$wpdisplayname = get_blog_option($blogid, 'walktheweb_wpdisplayname', esc_attr($user->display_name));	
				$buildingid = get_blog_option($blogid, 'walktheweb_buildingid', '');
				$buildingname = get_blog_option($blogid, 'walktheweb_buildingname', esc_attr($user->user_login));
				$buildingsnapshotid = get_blog_option($blogid, 'walktheweb_buildingsnapshotid', '');
				$communityid = get_blog_option($blogid, 'walktheweb_communityid', '');
				$communityname = get_blog_option($blogid, 'walktheweb_communityname', esc_attr($user->user_login));
				$communitysnapshotid = get_blog_option($blogid, 'walktheweb_communitysnapshotid', '');
				$woocommercekey = get_blog_option($blogid, 'walktheweb_woocommercekey', '');
				$woocommercesecret = get_blog_option($blogid, 'walktheweb_woocommercesecret', '');
				$siteurlpart = get_blog_option($blogid, 'walktheweb_siteurlpart', esc_attr($user->user_login));
				$siteurl = get_blog_option($blogid, 'walktheweb_siteurl', esc_url('https://3d.walktheweb.com'));
				$showstep = get_blog_option($blogid, 'walktheweb_showstep', '1');
				$showwizard = get_blog_option($blogid, 'walktheweb_showwizard', '0');
			} else {
				$storename = get_option('walktheweb_storename', esc_attr(get_bloginfo('name')));
				$wtwuserid = get_option('walktheweb_wtwuserid', '');
				$wtwuserid2 = get_option('walktheweb_wtwuserid2', '');
				$wtwlogin = get_option('walktheweb_wtwlogin', '');
				$wtwapikey = get_option('walktheweb_wtwapikey', '');
				$wtwapisecret = get_option('walktheweb_wtwapisecret', '');
				$wtw3duserid = get_option('walktheweb_wtw3duserid', '');
				$wwwstoreurl = get_option('walktheweb_wwwstoreurl', esc_url(get_bloginfo('wpurl')));
				$wwwstorecarturl = get_option('walktheweb_wwwstorecarturl', esc_url($wwwstoreurl."/cart/"));
				$wwwstoreproducturl = get_option('walktheweb_wwwstoreproducturl', esc_url($wwwstoreurl."/product/"));
				$wwwstorewoocommerceapiurl = get_option('walktheweb_wwwstorewoocommerceapiurl', esc_url($wwwstoreurl."/wp-json/wc/v2/"));
				$wpuserid = get_option('walktheweb_wpuserid', esc_attr($user->ID));
				$wplogin = get_option('walktheweb_wplogin', esc_attr($user->user_login));
				$wpemail = get_option('walktheweb_wpemail', esc_attr($user->user_email));
				$wpdisplayname = get_option('walktheweb_wpdisplayname', esc_attr($user->display_name));	
				$buildingid = get_option('walktheweb_buildingid', '');
				$buildingname = get_option('walktheweb_buildingname', esc_attr($user->user_login));
				$buildingsnapshotid = get_option('walktheweb_buildingsnapshotid', '');
				$communityid = get_option('walktheweb_communityid', '');
				$communityname = get_option('walktheweb_communityname', esc_attr($user->user_login));
				$communitysnapshotid = get_option('walktheweb_communitysnapshotid', '');
				$woocommercekey = get_option('walktheweb_woocommercekey', '');
				$woocommercesecret = get_option('walktheweb_woocommercesecret', '');
				$siteurlpart = get_option('walktheweb_siteurlpart', esc_attr($user->user_login));
				$siteurl = get_option('walktheweb_siteurl', esc_url('https://3d.walktheweb.com'));
				$showstep = get_option('walktheweb_showstep', '1');
				$showwizard = get_option('walktheweb_showwizard', '0');			
			}
			$mybuildingid = '';
			$mycommunityid = '';
			$wwwstoreip = "";
			
			if ($wtwlogin != "") {
				$showstep = "3";
			}
			$domain = $_SERVER['HTTP_HOST'];
			try {
				$host_names = explode(".", $domain);
				if (count($host_names) > 2) {
					$domain = $host_names[count($host_names)-2].".".$host_names[count($host_names)-1];
				} else {
					$domain = $host_names[0].".".$host_names[1];
				}
			} catch (Exception $e) {
				//echo $e->getMessage();
			}
			
			if ($_SERVER['REQUEST_METHOD']=='POST') {
				if ($_POST['walktheweb_nonce'] == $noncecheck && !empty($noncecheck)) {
					wp_cache_delete ('alloptions', 'options');
					$storename = sanitize_text_field($_POST["walktheweb_storename"]);
					$siteurlpart = sanitize_user($_POST["walktheweb_siteurlpart"], true);
					$siteurl = esc_url_raw($_POST["walktheweb_siteurl"]);
					$wtwuserid = sanitize_user($_POST["walktheweb_wtwuserid"], true);
					$wtwuserid2 = sanitize_user($_POST["walktheweb_wtwuserid2"], true);
					$wtw3duserid = sanitize_user($_POST["walktheweb_wtw3duserid"], true);
					$wtwlogin = sanitize_user($_POST["walktheweb_wtwlogin"], true);
					$wtwapikey = sanitize_key($_POST["walktheweb_wtwapikey"]);
					$wtwapisecret = sanitize_key($_POST["walktheweb_wtwapisecret"]);
					$wpuserid = sanitize_user($_POST["walktheweb_wpuserid"]);
					$wwwstoreurl = esc_url_raw($_POST["walktheweb_wwwstoreurl"]);
					$wwwstoreip = sanitize_text_field($_POST["walktheweb_wwwstoreip"]);
					$wwwstorecarturl = esc_url_raw($_POST["walktheweb_wwwstorecarturl"]);
					$wwwstoreproducturl = esc_url_raw($_POST["walktheweb_wwwstoreproducturl"]);
					$wwwstorewoocommerceapiurl = esc_url_raw($_POST["walktheweb_wwwstorewoocommerceapiurl"]);
					$wplogin = sanitize_user($_POST["walktheweb_wplogin"], true);
					$wpemail = sanitize_email($_POST["walktheweb_wpemail"]);
					$wpdisplayname = sanitize_text_field($_POST["walktheweb_wpdisplayname"]);
					$buildingid = sanitize_key($_POST["walktheweb_buildingid"]);
					$buildingname = sanitize_text_field($_POST["walktheweb_buildingname"]);
					$buildingsnapshotid = sanitize_key($_POST["walktheweb_buildingsnapshotid"]);
					$communityid = sanitize_key($_POST["walktheweb_communityid"]);
					$communityname = sanitize_text_field($_POST["walktheweb_communityname"]);
					$communitysnapshotid = sanitize_key($_POST["walktheweb_communitysnapshotid"]);
					$woocommercekey = sanitize_key($_POST["walktheweb_woocommercekey"]);
					$woocommercesecret = sanitize_key($_POST["walktheweb_woocommercesecret"]);
					$showstep = sanitize_key($_POST["walktheweb_showstep"]);
					$showwizard = sanitize_key($_POST["walktheweb_showwizard"]);
					if (is_multisite()) {
						if (get_blog_option($blogid, 'walktheweb_storename') !== false) {
							update_blog_option($blogid, 'walktheweb_storename', $storename);
						} else {
							add_blog_option($blogid, 'walktheweb_storename', $storename, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_siteurlpart') !== false) {
							update_blog_option($blogid, 'walktheweb_siteurlpart', $siteurlpart);
						} else {
							add_blog_option($blogid, 'walktheweb_siteurlpart', $siteurlpart, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_siteurl') !== false) {
							update_blog_option($blogid, 'walktheweb_siteurl', $siteurl);
						} else {
							add_blog_option($blogid, 'walktheweb_siteurl', $siteurl, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_wtwuserid') !== false) {
							update_blog_option($blogid, 'walktheweb_wtwuserid', $wtwuserid);
						} else {
							add_blog_option($blogid, 'walktheweb_wtwuserid', $wtwuserid, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_wtwuserid2') !== false) {
							update_blog_option($blogid, 'walktheweb_wtwuserid2', $wtwuserid2);
						} else {
							add_blog_option($blogid, 'walktheweb_wtwuserid2', $wtwuserid2, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_wtw3duserid') !== false) {
							update_blog_option($blogid, 'walktheweb_wtw3duserid', $wtw3duserid);
						} else {
							add_blog_option($blogid, 'walktheweb_wtw3duserid', $wtw3duserid, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_wtwlogin') !== false) {
							update_blog_option($blogid, 'walktheweb_wtwlogin', $wtwlogin);
						} else {
							add_blog_option($blogid, 'walktheweb_wtwlogin', $wtwlogin, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_wtwapikey') !== false) {
							update_blog_option($blogid, 'walktheweb_wtwapikey', $wtwapikey);
						} else {
							add_blog_option($blogid, 'walktheweb_wtwapikey', $wtwapikey, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_wtwapisecret') !== false) {
							update_blog_option($blogid, 'walktheweb_wtwapisecret', $wtwapisecret);
						} else {
							add_blog_option($blogid, 'walktheweb_wtwapisecret', $wtwapisecret, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_wpuserid') !== false) {
							update_blog_option($blogid, 'walktheweb_wpuserid', $wpuserid);
						} else {
							add_blog_option($blogid, 'walktheweb_wpuserid', $wpuserid, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_wwwstoreurl') !== false) {
							update_blog_option($blogid, 'walktheweb_wwwstoreurl', $wwwstoreurl);
						} else {
							add_blog_option($blogid, 'walktheweb_wwwstoreurl', $wwwstoreurl, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_wwwstoreip') !== false) {
							update_blog_option($blogid, 'walktheweb_wwwstoreip', $wwwstoreip);
						} else {
							add_blog_option($blogid, 'walktheweb_wwwstoreip', $wwwstoreip, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_wwwstorecarturl') !== false) {
							update_blog_option($blogid, 'walktheweb_wwwstorecarturl', $wwwstorecarturl);
						} else {
							add_blog_option($blogid, 'walktheweb_wwwstorecarturl', $wwwstorecarturl, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_wwwstoreproducturl') !== false) {
							update_blog_option($blogid, 'walktheweb_wwwstoreproducturl', $wwwstoreproducturl);
						} else {
							add_blog_option($blogid, 'walktheweb_wwwstoreproducturl', $wwwstoreproducturl, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_wwwstorewoocommerceapiurl') !== false) {
							update_blog_option($blogid, 'walktheweb_wwwstorewoocommerceapiurl', $wwwstorewoocommerceapiurl);
						} else {
							add_blog_option($blogid, 'walktheweb_wwwstorewoocommerceapiurl', $wwwstorewoocommerceapiurl, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_wplogin') !== false) {
							update_blog_option($blogid, 'walktheweb_wplogin', $wplogin);
						} else {
							add_blog_option($blogid, 'walktheweb_wplogin', $wplogin, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_wpemail') !== false) {
							update_blog_option($blogid, 'walktheweb_wpemail', $wpemail);
						} else {
							add_blog_option($blogid, 'walktheweb_wpemail', $wpemail, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_wpdisplayname') !== false) {
							update_blog_option($blogid, 'walktheweb_wpdisplayname', $wpdisplayname);
						} else {
							add_blog_option($blogid, 'walktheweb_wpdisplayname', $wpdisplayname, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_buildingid') !== false) {
							update_blog_option($blogid, 'walktheweb_buildingid', $buildingid);
						} else {
							add_blog_option($blogid, 'walktheweb_buildingid', $buildingid, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_buildingname') !== false) {
							update_blog_option($blogid, 'walktheweb_buildingname', $buildingname);
						} else {
							add_blog_option($blogid, 'walktheweb_buildingname', $buildingname, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_buildingsnapshotid') !== false) {
							update_blog_option($blogid, 'walktheweb_buildingsnapshotid', $buildingsnapshotid);
						} else {
							add_blog_option($blogid, 'walktheweb_buildingsnapshotid', $buildingsnapshotid, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_communityid') !== false) {
							update_blog_option($blogid, 'walktheweb_communityid', $communityid);
						} else {
							add_blog_option($blogid, 'walktheweb_communityid', $communityid, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_communityname') !== false) {
							update_blog_option($blogid, 'walktheweb_communityname', $communityname);
						} else {
							add_blog_option($blogid, 'walktheweb_communityname', $communityname, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_communitysnapshotid') !== false) {
							update_blog_option($blogid, 'walktheweb_communitysnapshotid', $communitysnapshotid);
						} else {
							add_blog_option($blogid, 'walktheweb_communitysnapshotid', $communitysnapshotid, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_woocommercekey') !== false) {
							update_blog_option($blogid, 'walktheweb_woocommercekey', $woocommercekey);
						} else {
							add_blog_option($blogid, 'walktheweb_woocommercekey', $woocommercekey, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_woocommercesecret') !== false) {
							update_blog_option($blogid, 'walktheweb_woocommercesecret', $woocommercesecret);
						} else {
							add_blog_option($blogid, 'walktheweb_woocommercesecret', $woocommercesecret, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_showstep') !== false) {
							update_blog_option($blogid, 'walktheweb_showstep', $showstep);
						} else {
							add_blog_option($blogid, 'walktheweb_showstep', $showstep, null, 'no');
						}
						if (get_blog_option($blogid, 'walktheweb_showwizard') !== false) {
							update_blog_option($blogid, 'walktheweb_showwizard', $showwizard);
						} else {
							add_blog_option($blogid, 'walktheweb_showwizard', $showwizard, null, 'no');
						}
					} else {
						if (get_option('walktheweb_storename') !== false) {
							update_option('walktheweb_storename', $storename);
						} else {
							add_option('walktheweb_storename', $storename, null, 'no');
						}
						if (get_option('walktheweb_siteurlpart') !== false) {
							update_option('walktheweb_siteurlpart', $siteurlpart);
						} else {
							add_option('walktheweb_siteurlpart', $siteurlpart, null, 'no');
						}
						if (get_option('walktheweb_siteurl') !== false) {
							update_option('walktheweb_siteurl', $siteurl);
						} else {
							add_option('walktheweb_siteurl', $siteurl, null, 'no');
						}
						if (get_option('walktheweb_wtwuserid') !== false) {
							update_option('walktheweb_wtwuserid', $wtwuserid);
						} else {
							add_option('walktheweb_wtwuserid', $wtwuserid, null, 'no');
						}
						if (get_option('walktheweb_wtwuserid2') !== false) {
							update_option('walktheweb_wtwuserid2', $wtwuserid2);
						} else {
							add_option('walktheweb_wtwuserid2', $wtwuserid2, null, 'no');
						}
						if (get_option('walktheweb_wtw3duserid') !== false) {
							update_option('walktheweb_wtw3duserid', $wtw3duserid);
						} else {
							add_option('walktheweb_wtw3duserid', $wtw3duserid, null, 'no');
						}
						if (get_option('walktheweb_wtwlogin') !== false) {
							update_option('walktheweb_wtwlogin', $wtwlogin);
						} else {
							add_option('walktheweb_wtwlogin', $wtwlogin, null, 'no');
						}
						if (get_option('walktheweb_wtwapikey') !== false) {
							update_option('walktheweb_wtwapikey', $wtwapikey);
						} else {
							add_option('walktheweb_wtwapikey', $wtwapikey, null, 'no');
						}
						if (get_option('walktheweb_wtwapisecret') !== false) {
							update_option('walktheweb_wtwapisecret', $wtwapisecret);
						} else {
							add_option('walktheweb_wtwapisecret', $wtwapisecret, null, 'no');
						}
						if (get_option('walktheweb_wpuserid') !== false) {
							update_option('walktheweb_wpuserid', $wpuserid);
						} else {
							add_option('walktheweb_wpuserid', $wpuserid, null, 'no');
						}
						if (get_option('walktheweb_wwwstoreurl') !== false) {
							update_option('walktheweb_wwwstoreurl', $wwwstoreurl);
						} else {
							add_option('walktheweb_wwwstoreurl', $wwwstoreurl, null, 'no');
						}
						if (get_option('walktheweb_wwwstoreip') !== false) {
							update_option('walktheweb_wwwstoreip', $wwwstoreip);
						} else {
							add_option('walktheweb_wwwstoreip', $wwwstoreip, null, 'no');
						}
						if (get_option('walktheweb_wwwstorecarturl') !== false) {
							update_option('walktheweb_wwwstorecarturl', $wwwstorecarturl);
						} else {
							add_option('walktheweb_wwwstorecarturl', $wwwstorecarturl, null, 'no');
						}
						if (get_option('walktheweb_wwwstoreproducturl') !== false) {
							update_option('walktheweb_wwwstoreproducturl', $wwwstoreproducturl);
						} else {
							add_option('walktheweb_wwwstoreproducturl', $wwwstoreproducturl, null, 'no');
						}
						if (get_option('walktheweb_wwwstorewoocommerceapiurl') !== false) {
							update_option('walktheweb_wwwstorewoocommerceapiurl', $wwwstorewoocommerceapiurl);
						} else {
							add_option('walktheweb_wwwstorewoocommerceapiurl', $wwwstorewoocommerceapiurl, null, 'no');
						}
						if (get_option('walktheweb_wplogin') !== false) {
							update_option('walktheweb_wplogin', $wplogin);
						} else {
							add_option('walktheweb_wplogin', $wplogin, null, 'no');
						}
						if (get_option('walktheweb_wpemail') !== false) {
							update_option('walktheweb_wpemail', $wpemail);
						} else {
							add_option('walktheweb_wpemail', $wpemail, null, 'no');
						}
						if (get_option('walktheweb_wpdisplayname') !== false) {
							update_option('walktheweb_wpdisplayname', $wpdisplayname);
						} else {
							add_option('walktheweb_wpdisplayname', $wpdisplayname, null, 'no');
						}
						if (get_option('walktheweb_buildingid') !== false) {
							update_option('walktheweb_buildingid', $buildingid);
						} else {
							add_option('walktheweb_buildingid', $buildingid, null, 'no');
						}
						if (get_option('walktheweb_buildingname') !== false) {
							update_option('walktheweb_buildingname', $buildingname);
						} else {
							add_option('walktheweb_buildingname', $buildingname, null, 'no');
						}
						if (get_option('walktheweb_buildingsnapshotid') !== false) {
							update_option('walktheweb_buildingsnapshotid', $buildingsnapshotid);
						} else {
							add_option('walktheweb_buildingsnapshotid', $buildingsnapshotid, null, 'no');
						}
						if (get_option('walktheweb_communityid') !== false) {
							update_option('walktheweb_communityid', $communityid);
						} else {
							add_option('walktheweb_communityid', $communityid, null, 'no');
						}
						if (get_option('walktheweb_communityname') !== false) {
							update_option('walktheweb_communityname', $communityname);
						} else {
							add_option('walktheweb_communityname', $communityname, null, 'no');
						}
						if (get_option('walktheweb_communitysnapshotid') !== false) {
							update_option('walktheweb_communitysnapshotid', $communitysnapshotid);
						} else {
							add_option('walktheweb_communitysnapshotid', $communitysnapshotid, null, 'no');
						}
						if (get_option('walktheweb_woocommercekey') !== false) {
							update_option('walktheweb_woocommercekey', $woocommercekey);
						} else {
							add_option('walktheweb_woocommercekey', $woocommercekey, null, 'no');
						}
						if (get_option('walktheweb_woocommercesecret') !== false) {
							update_option('walktheweb_woocommercesecret', $woocommercesecret);
						} else {
							add_option('walktheweb_woocommercesecret', $woocommercesecret, null, 'no');
						}
						if (get_option('walktheweb_showstep') !== false) {
							update_option('walktheweb_showstep', $showstep);
						} else {
							add_option('walktheweb_showstep', $showstep, null, 'no');
						}
						if (get_option('walktheweb_showwizard') !== false) {
							update_option('walktheweb_showwizard', $showwizard);
						} else {
							add_option('walktheweb_showwizard', $showwizard, null, 'no');
						}
					}
				}
			}
			if (!isset($storename) || empty($storename)) {
				$storename = get_bloginfo('name');
			} 
			if(!isset($showwizard) || empty($showwizard)) {
				$showwizard = '0';
			}
	?>	<div class="wtw_hidden">
			<input type="hidden" class="wtw_hidden" id="walktheweb_nonce" name="walktheweb_nonce" value="<?php echo $nonce; ?>" />
			<input type="hidden" class="wtw_hidden" id="walktheweb_wpuserid" name="walktheweb_wpuserid" value="<?php echo esc_attr($wpuserid); ?>" />
			<input type="hidden" class="wtw_hidden" id="walktheweb_wwwstoreurl" name="walktheweb_wwwstoreurl" value="<?php echo esc_url($wwwstoreurl); ?>" />
			<input type="hidden" class="wtw_hidden" id="walktheweb_wwwstoreip" name="walktheweb_wwwstoreip" value="<?php echo esc_attr($wwwstoreip); ?>" />
			<input type="hidden" class="wtw_hidden" id="walktheweb_wplogin" name="walktheweb_wplogin" value="<?php echo esc_attr($wplogin); ?>" />
			<input type="hidden" class="wtw_hidden" id="walktheweb_wtwlogin" name="walktheweb_wtwlogin" value="<?php echo esc_attr($wtwlogin); ?>" />
			<input type="hidden" class="wtw_hidden" id="walktheweb_wtwapikey" name="walktheweb_wtwapikey" value="<?php echo esc_attr($wtwapikey); ?>" />
			<input type="hidden" class="wtw_hidden" id="walktheweb_wtwapisecret" name="walktheweb_wtwapisecret" value="<?php echo esc_attr($wtwapisecret); ?>" />
			<input type="hidden" class="wtw_hidden" id="walktheweb_wtw3duserid" name="walktheweb_wtw3duserid" value="<?php echo esc_attr($wtw3duserid); ?>" />
			<input type="hidden" class="wtw_hidden" id="walktheweb_wpemail" name="walktheweb_wpemail" value="<?php echo esc_attr($wpemail); ?>" />
			<input type="hidden" class="wtw_hidden" id="walktheweb_wpdisplayname" name="walktheweb_wpdisplayname" value="<?php echo esc_attr($wpdisplayname); ?>" />
			<input type="hidden" class="wtw_hidden" id="walktheweb_siteurl" name="walktheweb_siteurl" value="<?php echo esc_attr($siteurl); ?>" />
			<input type="hidden" class="wtw_hidden" id="walktheweb_buildingid" name="walktheweb_buildingid" value="<?php echo esc_attr($buildingid); ?>" />
			<input type="hidden" class="wtw_hidden" id="walktheweb_buildingname" name="walktheweb_buildingname" value="<?php echo esc_attr($buildingname); ?>" />
			<input type="hidden" class="wtw_hidden" id="walktheweb_buildingsnapshotid" name="walktheweb_buildingsnapshotid" value="<?php echo esc_attr($buildingsnapshotid); ?>" />
			<input type="hidden" class="wtw_hidden" id="walktheweb_communityid" name="walktheweb_communityid" value="<?php echo esc_attr($communityid); ?>" />
			<input type="hidden" class="wtw_hidden" id="walktheweb_communityname" name="walktheweb_communityname" value="<?php echo esc_attr($communityname); ?>" />
			<input type="hidden" class="wtw_hidden" id="walktheweb_communitysnapshotid" name="walktheweb_communitysnapshotid" value="<?php echo esc_attr($communitysnapshotid); ?>" />
			<input type="hidden" class="wtw_hidden" id="walktheweb_mybuildingid" name="walktheweb_mybuildingid" value="<?php echo esc_attr($mybuildingid); ?>" />
			<input type="hidden" class="wtw_hidden" id="walktheweb_mycommunityid" name="walktheweb_mycommunityid" value="<?php echo esc_attr($mycommunityid); ?>" />
			<input type="hidden" class="wtw_hidden" id="walktheweb_showstep" name="walktheweb_showstep" value="<?php echo esc_attr($showstep); ?>" />
			<input type="hidden" class="wtw_hidden" id="walktheweb_showwizard" name="walktheweb_showwizard" value="<?php echo esc_attr($showwizard); ?>" />
			<input type="hidden" class="wtw_hidden" id="wtw_woocommerceisactive" name="wtw_woocommerceisactive" value="<?php echo esc_attr($wtw_woocommerceisactive); ?>" />
		</div>
		<div id="wtw_tabmenu" class="wtw_tabmenu">
			<div id="wtw_tab1" class="wtw_tabs" onclick="wtw.save('1');"><?php _e( 'Welcome', 'walktheweb' ); ?></div>
			<div id="wtw_tab2" class="wtw_tabs" onclick="wtw.save('2');"><?php _e('3D Building Store', 'walktheweb' ); ?></div>
			<div id="wtw_tab3" class="wtw_tabs" onclick="wtw.save('3');"><?php _e('3D Community', 'walktheweb' ); ?></div>
			<div id="wtw_tab4" class="wtw_tabs" onclick="wtw.save('4');"><?php _e('3D Store Settings', 'walktheweb' ); ?></div>
			<div id="wtw_tab5" class="wtw_tabs" onclick="wtw.save('5');"><?php _e( 'Permissions', 'walktheweb' ); ?></div>
			<div id="wtw_tab6" class="wtw_tabs" onclick="wtw.save('6');"><?php _e('My 3D Websites', 'walktheweb' ); ?></div>
			<div id="wtw_tab7" class="wtw_tabs" onclick="wtw.save('7');"><?php _e( 'Premium Upgrades', 'walktheweb' ); ?></div>
			<div id="wtw_tab8" class="wtw_tabs" onclick="wtw.save('8');"><?php _e( 'Help', 'walktheweb' ); ?></div>
		</div>
		<div id="wtw_siteform1">
			<div class="wtw_wide">
				<img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer14" class="wtw_spacer" />
				<div class="wtw_wizardholder">
					<input type="button" id="wtw_bcreatewizard" value="<?php _e( 'Create a 3D Store', 'walktheweb' ); ?>" class="wtw_button wtw_startwizard" onclick="wtw.startWizard();" /><br />
					<div class="wtw_wide"><?php _e( '(start here)', 'walktheweb' ); ?></div>
				</div>
				<div class="wtw_message"><?php _e( "Add a <span class='wtw_blue wtw_bold'>3D Browsing Store</span> to your <strong>WooCommerce</strong> website in about 5 Minutes!", 'walktheweb' ); ?> &nbsp;&nbsp;&nbsp; <a href="https://www.walktheweb.com/3d-stores/" target="_blank"><?php _e( 'read more', 'walktheweb' ); ?></a></div>
				<div class="wtw_clear"></div>
			</div>
			<div class="wtw_clear"></div>
			<div id="wtw_requireswoocommerce" class="wtw_woocommercerequired">
				<br /><div><?php _e( 'To begin, you must first install and activate the', 'walktheweb' ); ?> <a href="<?php echo esc_url(site_url()); ?>/wp-admin/plugin-install.php?s=woocommerce&tab=search&type=term">WooCommerce plugin</a>.<br /><br /></div>
			</div>
			<div class="wtw_clear"></div>
			
			<div class="wtw_wide"><img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer15" class="wtw_spacer" />
				<h3 class="wtw_searchheader"><?php _e( 'Welcome to', 'walktheweb' ); ?> <span class="wtw_wtwyellow">Walk the Web<sup>®</sup></span> - <?php _e( '3D Browsing', 'walktheweb' ); ?>!</h3>
				<div class="wtw_roundpage"><br />
					<div>
						<div class="wtw_center">
							<img id="wtw_iwelcome" src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/3dcommunitystores.jpg" class="wtw_welcomeimage" /><br />
							<div class="wtw_larger"><span class="wtw_wtwblue">Walk the Web<sup>®</sup></span> <?php _e( 'is like having a real <strong>3D Store</strong> in a Video Game!', 'walktheweb' ); ?></div>
						</div>
					</div>
					<div class="wtw_clear"></div><br />
				</div><br /><br />

				<h3 class="wtw_searchheader"><span class="wtw_wtwyellow">Walk the Web<sup>®</sup></span> - <?php _e( '3D Shopping Experience', 'walktheweb' ); ?></h3>
				<div class="wtw_roundpage"><br />
					<div>
						<div class="wtw_center wtw_larger">
							<?php _e( '<strong>Your 3D Store</strong> will display the products titles, images, pricing, and descriptions from WooCommerce.', 'walktheweb' ); ?><br /><br />
							<div class="wtw_left">
								<?php _e( '<strong>Your 3D Store</strong> offers an additional way to display and draw attention to your existing WooCommerce store and products. All product maintenance, additions, edits, sales transactions, and shopping cart functionality <strong>remain in your existing online store</strong>.', 'walktheweb' ); ?><br /><br />
							</div>
							<img id="wtw_iwelcomeproductdisplay" src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/productdisplay.jpg" class="wtw_productimage" />
						</div>
					</div>
					<div class="wtw_clear"></div><br />
				</div><br /><br />
			</div>		
		</div>

		<div id="wtw_haswoocommerce" class="wtw_wide">
			<div id="wtw_wizardbox" class="wtw_wizardbox wtw_hidden">
				<a href="#" id="wtw_cancelwizard" onclick="wtw.cancelWizard('1');event.preventDefault();" class="wtw_closewizard wtw_floatright"><?php _e( 'Cancel Wizard', 'walktheweb' ); ?> [x]</a>
				<h3 id="wtw_wizardtitle" class="wtw_wizardtitle"><?php _e( 'Wizard', 'walktheweb' ); ?></h3>
				<div id="wtw_wizardinstructions" class="wtw_wizardinstructions"><?php _e( 'Here are some instructions.', 'walktheweb' ); ?></div>
				<input type="button" id="wtw_bwizardlast" value="Back" onclick="" class="wtw_buttonwizardback" />
				<input type="button" id="wtw_bwizardnext" value="Continue" onclick="" class="wtw_buttonwizardnext" />
				<div id="wtw_permissionsset" class='wtw_permissionsset'><br /><?php _e( 'Permissions are set', 'walktheweb' ); ?> --></div>
				<div class="wtw_clear"></div>
			</div>
			<div id="wtw_loadingwizard" class="wtw_roundpage wtw_tall">
				<div class="wtw_loadingshow">- - - - - <?php _e( 'Loading', 'walktheweb' ); ?> - - - - -</div>
			</div>
			<div id="wtw_siteform2" class="wtw_widehidden">
				<img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer13" class="wtw_spacer" />
				<div class="wtw_wide"><img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer6" class="wtw_spacer" />
					<h3 class="wtw_searchheader"><span class="wtw_wtwyellow">Walk the Web<sup>®</sup></span> - <?php _e( 'My New 3D Building', 'walktheweb' ); ?></h3>
					<div class="wtw_roundpage"><br />
						<div>
							<div class="wtw_center">
								<h3 id="wtw_showbuildingname" class="wtw_heading"></h3>
								<img id='wtw_ibuilding' src='' class="wtw_imagepreview" />
							</div>
						</div>
						<div class="wtw_clear"></div><br />
						<div class="wtw_center">
							<input type="button" id="wtw_bshowbuildings" value="<?php _e( 'Select a 3D Building for your 3D Store', 'walktheweb' ); ?>" onclick="wtw.showBuildingSearch();" class="wtw_button" />
						</div>
					</div><br /><br />
				</div>		
			</div>	
			<div id="wtw_siteform2a" class="wtw_widehidden">
				<img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer12" class="wtw_spacer" />
				<h3 class="wtw_searchheader"><?php _e( 'Select a 3D Building for your 3D Store', 'walktheweb' ); ?></h3>
				<div class="wtw_roundpage"><br />
					<div id="wtw_loadingbuilding" class="wtw_loading">- - - - - <?php _e( 'Loading', 'walktheweb' ); ?> - - - - -</div>
					<div id="wtw_buildinglist"></div>
					<br />
					<i><?php _e( 'If you do not have enough products for the number of displays, the system will automatically repeat products until all product displays are full. You can also edit the 3D Building after these steps are complete to change the number, size, color, and placement of product displays. The help menu tab has links to full tutorials.', 'walktheweb' ); ?></i>
				</div><br /><br />
			</div>	

			<div id="wtw_siteform3" class="wtw_widehidden">
				<img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer10" class="wtw_spacer" />
				<div class="wtw_wide"><img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer6" class="wtw_spacer" />
					<h3 class="wtw_searchheader"><span class="wtw_wtwyellow">Walk the Web<sup>®</sup></span> - <?php _e( 'My New 3D Community', 'walktheweb' ); ?></h3>
					<div class="wtw_roundpage"><br />
						<div>
							<div class="wtw_center">
								<h3 id="wtw_showcommunityname" class="wtw_heading"></h3>
								<img id='wtw_icommunity' src='' class="wtw_imagepreview" />
							</div>
						</div>
						<div class="wtw_clear"></div><br />
						<div class="wtw_center">
							<input type="button" id="wtw_bshowcommunities" value="<?php _e( 'Select a 3D Community for your 3D Store', 'walktheweb' ); ?>" onclick="wtw.showCommunitySearch();" class="wtw_button" />
						</div>
					</div><br /><br />
				</div>		
			</div>	
			<div id="wtw_siteform3a" class="wtw_widehidden">
				<img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer11" class="wtw_spacer" />
				<h3 class="wtw_searchheader"><?php _e( 'Select a 3D Community for your 3D Store', 'walktheweb' ); ?></h3>
				<div class="wtw_roundpage"><br />
					<div id="wtw_loadingcommunity" class="wtw_loading">- - - - - <?php _e( 'Loading', 'walktheweb' ); ?> - - - - -</div>
					<div id="wtw_communitylist"></div>
				</div><br /><br />
			</div>	
			
			<div id="wtw_siteform4" class="wtw_widehidden">
				<img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer9" class="wtw_spacer" />
				<div class="wtw_wide"><img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer6" class="wtw_spacer" />
					<h3 class="wtw_searchheader"><span class="wtw_wtwyellow">Walk the Web<sup>®</sup></span> - <?php _e( '3D Store Settings', 'walktheweb' ); ?></h3>
					<div class="wtw_roundpage"><br />
						<div>
							<div class="wtw_confirmlabel wtw_indent2"><?php _e( '3D Store Name', 'walktheweb' ); ?><br /></div>
							<div class="wtw_inline"><input type="text" id="walktheweb_storename" name="walktheweb_storename" value="<?php echo esc_attr($storename); ?>" size="50" onkeypress="wtw.checkStoreName();" /><br />
								<?php _e( 'This will display on the front of your <strong>3D Store</strong>', 'walktheweb' ); ?>
							</div>
						</div>
						<div class="wtw_clear"></div><br />
						<div>
							<div class="wtw_confirmlabel wtw_indent2"><?php _e( '3D Website URL', 'walktheweb' ); ?><br /></div>
							<div class="wtw_inline">https://3d.walktheweb.com/<input type="text" id="walktheweb_siteurlpart" name="walktheweb_siteurlpart" value="<?php echo $siteurlpart; ?>" size="25" onkeydown="wtw.clearNameCheck();wtw.checkKeyPublishName(this);" onblur="wtw.finishKeyPublishName(this);" /><br />
								<div id="wtw_divnamecheck" class="wtw_checknameresults"> </div> 
								<input type="button" id="wtw_bcheckname" value="<?php _e( 'Check Name', 'walktheweb' ); ?>" onclick="wtw.checkName('walktheweb_siteurlpart', '');" class="wtw_button" />
							</div>
						</div>
						<div class="wtw_clear"></div><br />
						<div id="wtw_savedbyyoumessage" class="wtw_savedbyyoumessage"><?php _e( 'If you use this <strong>3D Website URL</strong> for your new 3D Store, your previous 3D Store will get changed to a new unique URL. You can find the new URL on the <strong>My 3D Websites</strong> Tab after your new 3D Store is created. Otherwise, you can select a different 3D Website URL above.', 'walktheweb' ); ?><br /><br /></div>
						<div class="wtw_center">
							<input type="button" id="wtw_bnameset" value="<?php _e( 'Continue', 'walktheweb' ); ?>" onclick="wtw.save('5');" class="wtw_button wtw_hidden wtw_iscentered wtw_largest" />
						</div>
					</div><br /><br />
				</div>
			</div>
			<div id="wtw_siteform5" class="wtw_widehidden">
				<img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer8" class="wtw_spacer" />
				<div id="wtw_registerform" class="wtw_wide"><img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer6" class="wtw_spacer" />
					<h3 class="wtw_searchheader"><div id="registersection" class="wtw_expandlink" onclick="wtw.togglePermissionSection(this);">Collapse Section [-]</div><span class="wtw_wtwyellow">Walk the Web<sup>®</sup></span> - <?php _e( 'Registration', 'walktheweb' ); ?></h3>
					<div id="registersectiondiv" class="wtw_roundpage" style="display:block;"><br />
						<div>
							<div class="wtw_confirmlabel wtw_indent2"><?php _e( 'Login', 'walktheweb' ); ?></div>
							<div class="wtw_inline"><input type="text" id="walktheweb_registerwtwuserid" name="walktheweb_registerwtwuserid" value="<?php echo esc_attr($wtwuserid); ?>" size="25" maxlength="64" /></div>
						</div>
						<div class="wtw_clear"></div><br />
						<div>
							<div class="wtw_confirmlabel wtw_indent2"><?php _e( 'Email', 'walktheweb' ); ?></div>
							<div class="wtw_inline"><input type="text" id="walktheweb_registerwtwemail" name="walktheweb_registerwtwemail" value="<?php echo esc_attr($wpemail); ?>" size="25"  onkeypress="event.preventDefault();" class="wtw_gray" maxlength="256" /></div>
						</div>
						<div class="wtw_clear"></div><br />
						<div>
							<div class="wtw_confirmlabel wtw_indent2"><?php _e( 'Password', 'walktheweb' ); ?></div>
							<div class="wtw_inline"><input type="password" id="walktheweb_registerwtwuserpassword" name="walktheweb_registerwtwuserpassword" value="" size="25" maxlength="64" /></div>
						</div>
						<div class="wtw_clear"></div><br />
						<div>
							<div class="wtw_confirmlabel wtw_indent2"><?php _e( 'Confirm Password', 'walktheweb' ); ?></div>
							<div class="wtw_inline"><input type="password" id="walktheweb_registerwtwuserpassword2" name="walktheweb_registerwtwuserpassword2" value="" size="25" maxlength="64" /><br /><br /></div>
							<div class="wtw_center"><input type="button" id="wtw_bregister" value="<?php _e( 'Register with', 'walktheweb' ); ?> Walk the Web" class="wtw_button" onclick="wtw.register();" /><br />
							<a href="#" onclick="wtw.changeForm('2');"><?php _e( 'Already have an account?', 'walktheweb' ); ?></a></div>
							<div id="wtw_registererror" class="wtw_loginerror"></div>
						</div>
						<div class="wtw_clear"></div><br />
					</div>
				</div>
				<div id="wtw_loginform" class="wtw_wide"><img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer5" class="wtw_spacer" />
					<h3 class="wtw_searchheader"><div id="loginsection" class="wtw_expandlink" onclick="wtw.togglePermissionSection(this);">Collapse Section [-]</div><span class="wtw_wtwyellow">Walk the Web<sup>®</sup></span> - <?php _e( 'Login', 'walktheweb' ); ?></h3>
					<div id="loginsectiondiv" class="wtw_roundpage" style="display:block;"><br />
						<div>
							<div class="wtw_confirmlabel wtw_indent2"><?php _e( 'Login', 'walktheweb' ); ?></div>
							<div class="wtw_inline"><input type="text" id="walktheweb_wtwuserid" name="walktheweb_wtwuserid" value="<?php echo esc_attr($wtwuserid); ?>" size="25" maxlength="64" /></div>
						</div>
						<div class="wtw_clear"></div><br />
						<div>
							<div class="wtw_confirmlabel wtw_indent2"><?php _e( 'Password', 'walktheweb' ); ?></div>
							<div class="wtw_inline"><input type="password" id="walktheweb_wtwuserpassword" name="walktheweb_wtwuserpassword" value="" size="25" maxlength="64" /><br /><br />
								<div class="wtw_center"><input type="button" id="wtw_blogin" value="<?php _e( 'Login with', 'walktheweb' ); ?> Walk the Web" onclick="wtw.checkAccount();" class="wtw_button" /><br />
								<a href="#" onclick="wtw.changeForm('1');"><?php _e( 'Need an account?', 'walktheweb' ); ?></a></div>
								<div id="wtw_loginerror" class="wtw_loginerror"></div>
							</div>
						</div>
						<div class="wtw_clear"></div><br />
					</div>
				</div>
				<div id="wtw_loggedinuserform" class="wtw_wide"><img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer4" class="wtw_spacer" />
					<h3 class="wtw_searchheader"><div id="loggedinsection" class="wtw_expandlink" onclick="wtw.togglePermissionSection(this);">Collapse Section [-]</div><span class="wtw_wtwyellow">Walk the Web<sup>®</sup></span> - <?php _e( 'Login Confirmed and Active', 'walktheweb' ); ?></h3>
					<div id="loggedinsectiondiv" class="wtw_roundpage" style="display:block;"><br />
						<div>
							<div class="wtw_confirmlabel wtw_indent2"><?php _e( 'Confirmed Login', 'walktheweb' ); ?></div>
							<div class="wtw_inline"><input type="text" class="wtw_gray" id="walktheweb_wtwuserid2" name="walktheweb_wtwuserid2" value="<?php echo esc_attr($wtwuserid2); ?>" size="25" onkeypress="event.preventDefault();" maxlength="64" /></div>
						</div>
						<div class="wtw_clear"></div><br />
						<div class="wtw_center"><input type="button" id="wtw_blogout" value="<?php _e( 'Log Out from', 'walktheweb' ); ?> Walk the Web" onclick="wtw.logoutAccount();" class="wtw_buttonfade" /></div><br />
						<div id="wtw_keyissued" class="wtw_keyissued"></div>
						<?php _e( 'You must remain logged in with the ', 'walktheweb' ); ?><span class="wtw_wtwblue">Walk the Web<sup>®</sup></span> <?php _e( 'Key set Active for this website to access your 3D Store Information (used for the <strong>My 3D Website Settings</strong> and <strong>Premium Upgrade</strong> Information).', 'walktheweb' ); ?><br /><br />
					</div>
				</div>

				<br />
				<img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer7" class="wtw_spacer" />
				<h3 class="wtw_searchheader"><div id="woosection" class="wtw_expandlink" onclick="wtw.togglePermissionSection(this);">Collapse Section [-]</div>WooCommerce API <?php _e( 'Settings', 'walktheweb' ); ?></h3>
				<div id="woosectiondiv" class="wtw_roundpage" style="display:block;">
					<?php _e( 'These settings allow your 3D Store to use your WooCommerce Products. Some of the buttons in this section may require you to allow pop-ups in your browser.', 'walktheweb' ); ?><br />
					<ol>
						<li><a id="wtw_findwooapi1" href="<?php echo esc_url(site_url()); ?>/wp-admin/admin.php?page=wc-settings&tab=api" target="_blank" class="wtw_buttontest"><?php _e( 'Find it here', 'walktheweb' ); ?></a><?php _e( 'Enable the', 'walktheweb' ); ?> WooCommerce REST API <br /><div class="wtw_clear"></div></li>
						<li><a id="wtw_findwooapi2" href="<?php echo esc_url(site_url()); ?>/wp-admin/admin.php?page=wc-settings&tab=api&section=keys" target="_blank" class="wtw_buttontest"><?php _e( 'Find it here', 'walktheweb' ); ?></a> <?php _e( 'Click <strong>Add Key</strong> under', 'walktheweb' ); ?> WooCommerce Keys/Apps link <br />
							<?php _e( 'Recommend the Description to be', 'walktheweb' ); ?> <strong><?php echo esc_url(site_url()); ?></strong> (<?php _e( 'any description is ok', 'walktheweb' ); ?>)<br /><?php _e( 'You will need', 'walktheweb' ); ?> <strong>read</strong> <?php _e( 'access', 'walktheweb' ); ?>.<div class="wtw_clear"></div></li>
						<li><?php _e( 'Insert the <strong>Key</strong> and <strong>Secret</strong> below and click <strong>Save Changes</strong>.', 'walktheweb' ); ?><br /></li>
					</ol><br />
					<div>
						<div class="wtw_confirmlabel wtw_indent2"><?php _e( 'Consumer Key', 'walktheweb' ); ?></div>
						<div class="wtw_inline"><input type="password" id="walktheweb_woocommercekey" name="walktheweb_woocommercekey" value="<?php echo esc_attr($woocommercekey); ?>" size="50" onkeypress="wtw.checkWooKeySet();" /></div>
					</div>
					<div class="wtw_clear"></div><br />
					<div>
						<div class="wtw_confirmlabel wtw_indent2"><?php _e( 'Consumer Secret', 'walktheweb' ); ?></div>
						<div class="wtw_inline"><input type="password" id="walktheweb_woocommercesecret" name="walktheweb_woocommercesecret" value="<?php echo esc_attr($woocommercesecret); ?>" size="50" onkeypress="wtw.checkWooKeySet();" /></div>
					</div>
					<div class="wtw_clear"></div><br />
					<div class="wtw_center">
						<input type="button" id="wtw_savewookey" value="Save WooCommerce API Settings" onclick="wtw.save('5');" class="wtw_button wtw_larger" /><br /><br />
						<a href="#" id="wtw_options1" class="wtw_optionslink" onclick="wtw.toggle(this, 'wtw_options1div');event.preventDefault();"><?php _e( 'Show Advanced Options', 'walktheweb' ); ?></a>
					</div>
					<div id="wtw_options1div" class="wtw_hidden" style="display:none;">
						<hr /><br />
						<div>
							<div class="wtw_confirmlabel wtw_indent2">WooCommerce API <?php _e( 'Base URL', 'walktheweb' ); ?></div>
							<a href="#" class="wtw_buttontest" onclick="this.href=document.getElementById('walktheweb_wwwstorewoocommerceapiurl').value+'products/categories/?per_page=5&orderby=slug&consumer_key=' + document.getElementById('walktheweb_woocommercekey').value + '&consumer_secret=' + document.getElementById('walktheweb_woocommercesecret').value;" target="_blank"><?php _e( 'Test', 'walktheweb' ); ?></a>
								<div class="wtw_inline"><input type="text" id="walktheweb_wwwstorewoocommerceapiurl" name="walktheweb_wwwstorewoocommerceapiurl" class="wtw_wideinput" value="<?php echo esc_url($wwwstorewoocommerceapiurl); ?>" size="50" /><br />
								<?php _e( 'Example', 'walktheweb' ); ?>: <strong><?php echo esc_url(site_url()); ?>/wp-json/wc/v2/</strong><br />
								<span class="wtw_testtext"><?php _e( 'Test Button', 'walktheweb' ); ?></span> <?php _e( 'should return a <i>blob</i> of data.', 'walktheweb' ); ?>
							</div>
						</div>
						<div class="wtw_clear"></div><br />
						<div>
							<div class="wtw_confirmlabel wtw_indent2"><?php _e( 'Product Base URL', 'walktheweb' ); ?></div>
							<a href="#" id="btestproduct" class="wtw_buttontest" onclick="wtw.setTestProductURL('walktheweb_wwwstorewoocommerceapiurl', 'walktheweb_wwwstoreproducturl', 'walktheweb_woocommercekey', 'walktheweb_woocommercesecret', 'btestproduct');event.preventDefault();" target="_blank"><?php _e( 'Test', 'walktheweb' ); ?></a>
								<div class="wtw_inline"><input type="text" id="walktheweb_wwwstoreproducturl" name="walktheweb_wwwstoreproducturl" class="wtw_wideinput" value="<?php echo esc_url($wwwstoreproducturl); ?>" size="50" /><br />
								<?php _e( 'Example', 'walktheweb' ); ?>: <strong><?php echo esc_url(site_url()); ?>/product/</strong><br />
								<span class="wtw_testtext"><?php _e( 'Test Button', 'walktheweb' ); ?></span> <?php _e( 'should show one of your Products.', 'walktheweb' ); ?>
							</div>
						</div>
						<div class="wtw_clear"></div><br />
						<div>
							<div class="wtw_confirmlabel wtw_indent2"><?php _e( 'Shopping Cart URL', 'walktheweb' ); ?></div>
							<a href="#" class="wtw_buttontest" onclick="wtw.checkLink(this.href=document.getElementById('walktheweb_wwwstorecarturl').value, 'walktheweb_wwwstorecarturl');" target="_blank"><?php _e( 'Test', 'walktheweb' ); ?></a>
								<div class="wtw_inline"><input type="text" id="walktheweb_wwwstorecarturl" name="walktheweb_wwwstorecarturl" class="wtw_wideinput" value="<?php echo esc_url($wwwstorecarturl); ?>" size="50" /><br />
								<?php _e( 'Example', 'walktheweb' ); ?>: <strong><?php echo esc_url(site_url()); ?>/cart/</strong><br />
								<span class="wtw_testtext"><?php _e( 'Test Button', 'walktheweb' ); ?></span> <?php _e( 'should show your Shopping Cart.', 'walktheweb' ); ?> 
							</div>
						</div>
						<div class="wtw_clear"></div><br />
					</div>
				</div>
				<div class="wtw_clear"></div><br /><br />
			</div>	
			<div id="wtw_siteform6" class="wtw_widehidden">
				<img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer" class="wtw_spacer" />
				<div class="wtw_widehidden" id="wtw_editwebsettings">
					<h3 class="wtw_searchheader"><?php _e( 'Edit 3D Store - Settings', 'walktheweb' ); ?></h3>
					<div class="wtw_roundpage">
						<div id="wtw_loadingeditsite" class="wtw_loading">- - - - - <?php _e( 'Loading', 'walktheweb' ); ?> - - - - -</div>
						<div id="wtw_editsiteready" class='wtw_widehidden'>
							<div class="wtw_clear"></div>
							<div class="wtw_center">
								<a href="" id="wtw_bvisitsite" class="wtw_button wtw_largest" target="_blank"><?php _e( 'Visit My 3D Store', 'walktheweb' ); ?></a>
							</div>
							<div class="wtw_clear"></div>
							<h3 class="wtw_3dsitename"><?php _e( '3D Community Store Website', 'walktheweb' ); ?></h3>
							<div>
								<div class="wtw_confirmlabel wtw_indent2"><?php _e( '3D Community Name', 'walktheweb' ); ?></div>
								<div class="wtw_inline"><input type="text" id="wtw_communityname" name="wtw_communityname" size="50" /><br />
									<?php _e( 'Shows on bottom left corner of <strong>3D Browsing</strong> window.', 'walktheweb' ); ?></div>
							</div>
							<div class="wtw_clear"></div><br />
							<div>
								<div class="wtw_confirmlabel wtw_indent2"><?php _e( '3D Community Store Website', 'walktheweb' ); ?></div>
								<div class="wtw_inline wtw_blue">https://3d.walktheweb.com/<input type="text" id="wtw_communitypublishname" name="wtw_communitypublishname" size="25" onkeydown="wtw.checkKeyPublishName(this);" onblur="wtw.finishKeyPublishName(this);" /><br />
									<div id="wtw_divnamecheck1" class="wtw_checknameresults"> </div> 
									<input type="button" id="wtw_bcheckcommunitypublishname" value="Check Name" onclick="wtw.checkName('wtw_communitypublishname', '1');" class="wtw_buttonfade wtw_floatright" /></div>
							</div>
							<div class="wtw_clear"></div><br />
							<div>
								<div class="wtw_confirmlabel wtw_indent2"><?php _e( '3D Community', 'walktheweb' ); ?> Google Analytics ID</div>
								<div class="wtw_inline"><input type="text" id="wtw_communityanalyticsid" name="wtw_communityanalyticsid" size="50" /></div>
							</div>
							<div class="wtw_clear"></div><br />
							<div class="wtw_center">
								<input type="button" id="wtw_bedit3dcommunity" value="<?php _e( 'Edit 3D Community Design', 'walktheweb' ); ?>" onclick="wtw.edit3dCommunityDesign();" class="wtw_buttonedit" />
								<div class="wtw_leftalign"><br />
									<?php _e( 'The 3D Community consists of the landscape, 3D Building locations, roads, sidewalks, terrains, and other items surrounding your 3D Store Building.', 'walktheweb' ); ?>
								</div><br />
							</div>
							<div class="wtw_clear"></div><br /><br />
							
							<h3 class="wtw_3dsitename"><?php _e( '3D Building Store', 'walktheweb' ); ?></h3>
							<div>
								<div class="wtw_confirmlabel wtw_indent2"><?php _e( '3D Building Name', 'walktheweb' ); ?></div>
								<div class="wtw_inline"><input type="text" id="wtw_buildingname" name="wtw_buildingname" size="50" /><br />
									<?php _e( 'Shows on bottom right corner of <strong>3D Browsing</strong> window.', 'walktheweb' ); ?></div>
							</div>
							<div class="wtw_clear"></div><br />
							<div>
								<div class="wtw_confirmlabel wtw_indent2"><?php _e( '3D Building Store Only', 'walktheweb' ); ?></div>
								<div class="wtw_inline wtw_blue">https://3d.walktheweb.com/building/<input type="text" id="wtw_publishname" name="wtw_publishname" size="15" onkeydown="wtw.checkKeyPublishName(this);" onblur="wtw.finishKeyPublishName(this);" /><br />
									<div id="wtw_divnamecheck2" class="wtw_checknameresults"> </div> 
									<input type="button" id="wtw_bcheckbuildingpublishname" value="<?php _e( 'Check Name', 'walktheweb' ); ?>" onclick="wtw.checkName('wtw_publishname', '2');" class="wtw_buttonfade wtw_floatright" /></div>
							</div>
							<div class="wtw_clear"></div><br />
							<div>
								<div class="wtw_confirmlabel wtw_indent2"><?php _e( 'Open traditional store Web Pages in iframe', 'walktheweb' ); ?></div>
								<div class="wtw_inline wtw_checkbox"><input type="checkbox" id="wtw_storeiframe" name="wtw_storeiframe" /> (<a href='https://www.walktheweb.com/wiki/products-in-iframe/' target='_blank'><?php _e( 'Requires Permissions, see Instructions', 'walktheweb' ); ?></a>)</div>
							</div>
							<div class="wtw_clear"></div><br />
							<div>
								<div class="wtw_confirmlabel wtw_indent2"><?php _e( '3D Building', 'walktheweb' ); ?> Google Analytics ID</div>
								<div class="wtw_inline"><input type="text" id="wtw_analyticsid" name="wtw_analyticsid" size="50" /></div>
							</div>
							<div class="wtw_clear"></div><br />
							<div class="wtw_center">
								<input type="button" id="wtw_bedit3dbuilding" value="<?php _e( 'Edit 3D Building Design', 'walktheweb' ); ?>" onclick="wtw.edit3dBuildingDesign();" class="wtw_buttonedit" />
								<div class="wtw_leftalign"><br />
								<?php _e( 'The 3D Building is your 3D Store. You can customize your 3D Building by adding, editing, or removing 3D Objects including the product displays, colors, textures, and even the 3D Building Blocks. The Editor Website also allows you to build 3D Buildings and 3D Communities from scratch or shared templates! It is all FREE. You only pay if you choose from our optional Premium Upgrades.', 'walktheweb' ); ?>
								</div><br />
							</div>
							<div class="wtw_clear"></div><br /><br />
							<h3 class="wtw_3dsitename">WooCommerce API <?php _e( 'Settings', 'walktheweb' ); ?></h3>
							<div>
								<div class="wtw_confirmlabel wtw_indent2"><?php _e( 'Consumer Key', 'walktheweb' ); ?></div>
								<div class="wtw_inline"><input type="password" id="wtw_woocommercekey" name="wtw_woocommercekey" size="50" /></div>
							</div>
							<div class="wtw_clear"></div><br />
							<div>
								<div class="wtw_confirmlabel wtw_indent2"><?php _e( 'Consumer Secret', 'walktheweb' ); ?></div>
								<div class="wtw_inline"><input type="password" id="wtw_woocommercesecret" name="wtw_woocommercesecret" size="50" /></div>
							</div>
							<div class="wtw_clear"></div><br />
							<div class="wtw_center">
								<a href="#" id="wtw_options2" class="wtw_optionslink" onclick="wtw.toggle(this, 'wtw_options2div');event.preventDefault();"><?php _e( 'Show Advanced Options', 'walktheweb' ); ?></a>
							</div><hr /><br />
							<div id="wtw_options2div" class="wtw_hidden" style="display:none;">
								<br />
								<div>
									<div class="wtw_confirmlabel wtw_indent2"><?php _e( 'Traditional Store URL', 'walktheweb' ); ?></div>
									<div class="wtw_inline"><input type="text" id="wtw_wwwstoreurl" name="wtw_wwwstoreurl" size="50" class="wtw_wideinput" /><br />
										<?php _e( 'Example', 'walktheweb' ); ?>: <strong><?php echo esc_url(site_url()); ?></strong>
									</div>
								</div>
								<div class="wtw_clear"></div><br />
								<div>
									<div class="wtw_confirmlabel wtw_indent2">WooCommerce API <?php _e( 'Base URL', 'walktheweb' ); ?></div>
									<a href="#" class="wtw_buttontest" onclick="this.href=document.getElementById('wtw_wwwstorewoocommerceapiurl').value+'products/categories/?per_page=5&orderby=slug&consumer_key=' + document.getElementById('wtw_woocommercekey').value + '&consumer_secret=' + document.getElementById('wtw_woocommercesecret').value;" target="_blank"><?php _e( 'Test', 'walktheweb' ); ?></a>
									<div class="wtw_inline"><input type="text" id="wtw_wwwstorewoocommerceapiurl" name="wtw_wwwstorewoocommerceapiurl" size="50" class="wtw_wideinput" /><br />
										<?php _e( 'Example', 'walktheweb' ); ?>: <strong><?php echo esc_url(site_url()); ?>/wp-json/wc/v2/</strong><br />
										<span class="wtw_testtext"><?php _e( 'Test Button', 'walktheweb' ); ?></span> <?php _e( 'should return a <i>blob</i> of data.', 'walktheweb' ); ?>.
									</div>
								</div>
								<div class="wtw_clear"></div><br />
								<div>
									<div class="wtw_confirmlabel wtw_indent2"><?php _e( 'Product Base URL', 'walktheweb' ); ?></div>
									<a href="#" id="btestproduct2" class="wtw_buttontest" onclick="wtw.setTestProductURL('wtw_wwwstorewoocommerceapiurl', 'wtw_wwwstoreproducturl', 'wtw_woocommercekey', 'wtw_woocommercesecret', 'btestproduct2');event.preventDefault();" target="_blank"><?php _e( 'Test', 'walktheweb' ); ?></a>
									<div class="wtw_inline"><input type="text" id="wtw_wwwstoreproducturl" name="wtw_wwwstoreproducturl" size="50" class="wtw_wideinput" /><br />
										<?php _e( 'Example', 'walktheweb' ); ?>: <strong><?php echo esc_url(site_url()); ?>/product/</strong><br />
										<span class="wtw_testtext"><?php _e( 'Test Button', 'walktheweb' ); ?></span> <?php _e( 'should show one of your Products.', 'walktheweb' ); ?>
									</div>
								</div>
								<div class="wtw_clear"></div><br />
								<div>
									<div class="wtw_confirmlabel wtw_indent2"><?php _e( 'Shopping Cart URL', 'walktheweb' ); ?></div>
									<a href="#" class="wtw_buttontest" onclick="wtw.checkLink(this.href=document.getElementById('wtw_wwwstorecarturl').value, 'wtw_wwwstorecarturl');" target="_blank"><?php _e( 'Test', 'walktheweb' ); ?></a>
									<div class="wtw_inline"><input type="text" id="wtw_wwwstorecarturl" name="wtw_wwwstorecarturl" size="50" class="wtw_wideinput" /><br />
										<?php _e( 'Example', 'walktheweb' ); ?>: <strong><?php echo esc_url(site_url()); ?>/cart/</strong><br />
										<span class="wtw_testtext"><?php _e( 'Test Button', 'walktheweb' ); ?></span> <?php _e( 'should show your Shopping Cart.', 'walktheweb' ); ?> 
									</div>
								</div>
								<div class="wtw_clear"></div><br /><hr /><br />
							</div>
							<input type="hidden" id="wtw_communityid" name="wtw_communityid" />
							<input type="hidden" id="wtw_buildingid" name="wtw_buildingid" />
							<input type="hidden" id="wtw_webaliasid" name="wtw_webaliasid" />
							<div class="wtw_center">
								<input type="button" id="wtw_bcancelupdateweb" value="Cancel" onclick="wtw.cancelUpdate3dWebsite();" class="wtw_buttoncancel" />
								<input type="button" id="wtw_bupdateweb" value="Save My 3D Website" onclick="wtw.update3dWebsite();" class="wtw_button wtw_indent" />
							</div>
						</div>
					</div><br />
				</div>
				<div class="wtw_wide" id="wtw_confirmcreate">
					<h3 class="wtw_searchheader"><?php _e( 'Final Step to Create Your 3D Store', 'walktheweb' ); ?></h3>
					<div class="wtw_roundpage">
						<div class="wtw_center">
							<input type="button" id="wtw_bcreate" value="<?php _e( 'Create It!', 'walktheweb' ); ?>" onclick="wtw.create3dWebsite();" class="wtw_button wtw_createit" /><br />
						</div>
						<div>
							<h3 id="walktheweb_storename2" class="wtw_floatleft wtw_indent wtw_heading"></h3>
							<div class="wtw_right"><input type="button" id="wtw_beditstorename" value="<?php _e( 'Edit', 'walktheweb' ); ?>" onclick="wtw.changeTab('4');" class="wtw_buttonfade" /></div>
						</div>
						<div class="wtw_clear"></div>
						<div>
							<div id="wtw_path" class="wtw_floatleft wtw_indent wtw_plaintext"></div>
							<div class="wtw_right"><input type="button" id="wtw_beditpublishname" value="<?php _e( 'Edit', 'walktheweb' ); ?>" onclick="wtw.changeTab('4');" class="wtw_buttonfade" /></div>
						</div>
						<div class="wtw_clear"></div><br /><br />
						<div>
							<div id="wtw_login2" class="wtw_floatleft wtw_indent wtw_plaintext"></div>
							<div class="wtw_right"><input type="button" id="wtw_beditloginname" value="<?php _e( 'Edit', 'walktheweb' ); ?>" onclick="wtw.changeTab('5');" class="wtw_buttonfade" /></div>
						</div>
						<div class="wtw_clear"></div><br />
						<div>
							<div id="wtw_wooapiaccess2" class="wtw_floatleft wtw_indent wtw_plaintext"></div>
							<div class="wtw_right"><input type="button" id="wtw_beditkeyname" value="<?php _e( 'Edit', 'walktheweb' ); ?>" onclick="wtw.changeTab('5');" class="wtw_buttonfade" /></div>
						</div>
						<div class="wtw_clear"></div><br />
						<div class="wtw_center">
							<div class="wtw_centered">
								<div class="wtw_imagebox">
									<img id='wtw_ibuilding2' src='' class="wtw_imageboxpreview" /><br />
									<div class="wtw_overlapup"><input type="button" id="wtw_beditbuilding" value="<?php _e( 'Edit', 'walktheweb' ); ?>" onclick="wtw.changeTab('2');" class="wtw_buttonfade" /></div>
								</div>
								<div class="wtw_plus">+</div>
								<div class="wtw_imagebox">
									<img id='wtw_icommunity2' src='' class="wtw_imageboxpreview" /><br />
									<div class="wtw_overlapup"><input type="button" id="wtw_beditcommunity" value="<?php _e( 'Edit', 'walktheweb' ); ?>" onclick="wtw.changeTab('3');" class="wtw_buttonfade" /></div>
								</div>
								<div class="wtw_clear"></div>
							</div>
						</div>
						<br />
					</div><br />
				</div>
				<div class="wtw_widehidden" id="wtw_confirmcreating">
					<img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer2" class="wtw_spacer" />
					<h3 class="wtw_searchheader"><?php _e( 'Creating Your New 3D Store', 'walktheweb' ); ?></h3>
					<div class="wtw_roundpage">
						<img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/construction.gif" id="wtw_iconstruction" class="wtw_constructionimage" />
						<img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/processing.gif" id="wtw_iprocessing" class="wtw_processingimage" />
					</div>
				</div>
				<div class="wtw_wide" id="wtw_new3dwebsite">
					<img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer20" class="wtw_spacer" />
					<h3 class="wtw_searchheader"><?php _e( 'My New 3D Store!', 'walktheweb' ); ?></h3>
					<div class="wtw_roundpage"><br />
						<div id="wtw_loadingnewsite" class="wtw_loading">- - - - - <?php _e( 'Loading', 'walktheweb' ); ?> - - - - -</div>
						<div id="wtw_newsiteready" class='wtw_widehidden'>
							<div class='wtw_siteready'><?php _e( 'Your New 3D Store is Ready!', 'walktheweb' ); ?></div>
							<div class="wtw_clear"></div>
							<div class="wtw_center">
								<a href="" id="wtw_bvisitsite2" class="wtw_buttonvisit" target="_blank"><?php _e( 'Visit My 3D Store', 'walktheweb' ); ?></a>
								<img id='wtw_ibuilding3' src='' class="wtw_imagefadepreview" /><div id='wtw_noimageplaceholder' class='wtw_noimageplaceholder'><br /><br /><br /></div>
								<div class='wtw_optupgradediv'>
									<div class='wtw_optupgrade'>
										Optional: Use your own domain name for just <span class='wtw_optupgradeprice'>$8.<sup class='wtw_optupgradeprice'>00</sup></span><br />U.S. per month (billed yearly)<br /><br /><br />
										<a href="" id="wtw_boptupgrade" class="wtw_buttonoptupgrade" target="_blank">http://3d.<span class='wtw_blue'>http3d.net</span></a><br /><div class='wtw_smaller'><?php _e( 'Click to Read More', 'walktheweb' ); ?></div><br />
									</div>
								</div>
								<div>
									Please check out the <strong><a href="#" onclick="wtw.save('8');event.preventDefault();"><?php _e( 'Help', 'walktheweb' ); ?></a></strong> tab and optional <strong><a href="#" onclick="wtw.save('7');event.preventDefault();"><?php _e( 'Premium Upgrades', 'walktheweb' ); ?></a></strong>
								</div><br /><br />
							</div>
							<div class="wtw_clear"></div>
							<a href="" id="wtw_bvisitedit" class="wtw_buttonfade wtw_floatleft wtw_indent2"><?php _e( 'Edit 3D Website Settings', 'walktheweb' ); ?></a>
							<a href="" id="wtw_bvisitlist" onclick="wtw.hide('wtw_new3dwebsite');wtw.get3dWebsites();event.preventDefault();" class="wtw_buttonfade wtw_floatright wtw_indentright2"><?php _e( 'List my 3D Websites', 'walktheweb' ); ?></a>
							<div class="wtw_clear"></div>
							<div class="wtw_floatleft wtw_indent2">(<?php _e( 'Includes', 'walktheweb' ); ?> Google Analytics ID <?php _e( 'and', 'walktheweb' ); ?> iframe <?php _e( 'settings', 'walktheweb' ); ?>)</div>
							<div class="wtw_clear"></div>
						</div>
					</div>
				</div>
				<div class="wtw_wide" id="wtw_confirmcreated">
					<img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer3" class="wtw_spacer" />
					<h3 class="wtw_searchheader"><?php _e( 'My 3D Stores', 'walktheweb' ); ?></h3>
					<div class="wtw_roundpage"><br />
						<div id="wtw_loadingsites" class="wtw_loading">- - - - - <?php _e( 'Loading', 'walktheweb' ); ?> - - - - -</div>
						<div id="wtw_sitelist"></div>
					</div>
				</div><br /><br />
			</div>	
			<div id="wtw_siteform7" class="wtw_widehidden">
				<img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer16" class="wtw_spacer" />
				<div class="wtw_wide"><img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer17" class="wtw_spacer" />
					<h3 class="wtw_searchheader"><span class="wtw_wtwyellow">Walk the Web<sup>®</sup></span> - <?php _e( 'Custom Solutions and Services', 'walktheweb' ); ?></h3>
					<div class="wtw_roundpage">
						<div class='wtw_sendideas'><?php _e( 'Send us your ideas', 'walktheweb' ); ?></div>
						<div class='wtw_sendideas2'><?php _e( 'We will give you a reasonable price to create it!', 'walktheweb' ); ?></div><br /><br />
						<div class='wtw_indent2 wtw_black wtw_larger'>
							<?php _e( 'Need something built in <strong>3D</strong>?', 'walktheweb' ); ?><br />
							<?php _e( 'Want your <strong>3D Building</strong> to look like <strong>Your real Building</strong>?', 'walktheweb' ); ?><br />
							<?php _e( 'Are you a <strong>virtual business</strong> and want to create an <strong>on-line image</strong>?', 'walktheweb' ); ?><br />
							<?php _e( 'Want to add a <strong>3D Game</strong> to draw attention to your <strong>3D Store</strong>?', 'walktheweb' ); ?><br />
						</div><br /><br />
						<div class='wtw_indent2 wtw_larger wtw_bolder'><?php _e( 'We custom build:', 'walktheweb' ); ?></div>
						<ul>
							<li class='wtw_indent3 wtw_larger'>• <span class='wtw_blue'>3D Things</span> <?php _e( 'like Product Displays, demos, 3D Objects.', 'walktheweb' ); ?></li>
							<li class='wtw_indent3 wtw_larger'>• <span class='wtw_blue'>3D Store Buildings</span> <?php _e( 'or add another 3D Building to your 3D Scene.', 'walktheweb' ); ?></li>
							<li class='wtw_indent3 wtw_larger'>• <span class='wtw_blue'>3D Community</span> <?php _e( 'scenes, landscape, cityscape, roads, trees, and more.', 'walktheweb' ); ?></li>
							<li class='wtw_indent3 wtw_larger'>• <span class='wtw_blue'>3D Games</span> <?php _e( 'first-person, arcade, or other games.', 'walktheweb' ); ?></li>
							<li class='wtw_indent3 wtw_larger'>• <span class='wtw_blue'>3D Amusement Park Rides</span> <?php _e( 'add fun rides for users.', 'walktheweb' ); ?></li>
						</ul>
						<div class="wtw_clear"></div><br />
						<div class='wtw_center'>
							<a href="https://www.pinterest.com/walktheweb/3d-walk-the-web-3dwalkthewebcom/" id="wtw_bpinterestlink" class="wtw_buttonaddtocart wtw_floatleft wtw_indent2" target="_blank"><?php _e( 'See our', 'walktheweb' ); ?> Pinterest Portfolio</a>
							<a href="https://www.walktheweb.com/services-products/" id="wtw_bcontactlink" class="wtw_buttonaddtocart wtw_floatright wtw_indentright2" target="_blank"><?php _e( 'Read more and Contact us to get started!', 'walktheweb' ); ?></a>
						</div>
						<div class="wtw_clear"></div><br />
					</div><br /><br />	
					<div id="wtw_customdomainoffer" class="wtw_wide">
						<h3 class="wtw_searchheaderoptional"><span class="wtw_wtwyellow">Walk the Web<sup>®</sup></span> - <?php _e( 'Optional Personal Upgrade', 'walktheweb' ); ?></h3>
						<div class="wtw_roundpageoptional">
							<h3 class="wtw_3dsitename"><div class='wtw_pricediv'>only <span class='wtw_price'>$8.<sup class='wtw_price'>00</sup></span> U.S. per month<br /><div class='wtw_floatright'>billed yearly</div></div>
								<?php _e( "<span class='wtw_bolder'>Personal Upgrade</span> <span class='wtw_black'>for Your 3D Store</span>", 'walktheweb' ); ?></h3>
							<div class="wtw_clear"></div>
							<div class="wtw_black wtw_indent2 wtw_larger wtw_bolder"><?php _e( 'Personal Upgrade Includes', 'walktheweb' ); ?></div><br />
							<div class="wtw_black wtw_indent3"><strong>• <?php _e( "Personalize your 3D Store by using your own Domain Name!", 'walktheweb' ); ?></strong> <?php _e( 'Example', 'walktheweb' ); ?>: <strong>http://3d.</strong>YourDomain.com</div><br />
							<div class="wtw_black wtw_indent3"><strong>• <?php _e( "Support your 3D Store with our blog community, tutorials, and email support.", 'walktheweb' ); ?></strong></div><br /><br />
							<div class="wtw_black wtw_center wtw_larger wtw_bolder"><span class='wtw_largest'>http://3d.<span class='wtw_blue'>YourDomainName.com</span></span></div><br />
							<div class="wtw_clear"></div>
							<div class="wtw_confirmlabel wtw_indent2"><?php _e( 'Your Domain Name', 'walktheweb' ); ?></div>
							<div class="wtw_inline">
								<div class='wtw_http3dcustom'>http://3d.</div><input type="text" id="walktheweb_siteurl2" name="walktheweb_siteurl2" class='wtw_customdomain' value="<?php echo esc_attr($domain); ?>" size="25" maxlength="256" /><br />
							</div>
							<div class="wtw_clear"></div><br />
							<div class="wtw_confirmlabel wtw_indent2"><?php _e( '3D Community to display', 'walktheweb' ); ?></div>
							<div class="wtw_inline">
								<select id="wtw_customdomaincommunityid"></select>
							</div><br /><br />
							<div class="wtw_center">
								<input type="button" id="wtw_baddtocartpersonal" value="<?php _e( 'View Purchase Options', 'walktheweb' ); ?>" onclick="wtw.addToCart('1');" class="wtw_buttonaddtocart" />
								<div class="wtw_clear"></div><br />
								<div class="wtw_black"><?php _e( 'Note that Multiple Domain Names can be set to display the same 3D Community Website.', 'walktheweb' ); ?></div><br />
								<div class='wtw_black'><strong>http://3d.</strong> or <strong>https://3d.</strong> are trademarks that show it is a <strong>HTTP3D Inc. 3D Browsing</strong> website.<br /></div><br />
								<div class='wtw_black'><a href="https://www.walktheweb.com/wiki/custom-domain-name-dns-setup/" target="_blank"><?php _e( 'Here is how to set the DNS settings to make it work.', 'walktheweb' ); ?></a></div><br />
							</div>
						</div><br /><br />				
						<h3 class="wtw_searchheaderoptional"><span class="wtw_wtwyellow">Walk the Web<sup>®</sup></span> - <?php _e( 'Optional Secure Business Service Plans', 'walktheweb' ); ?></h3>
						<div class="wtw_roundpageoptional">
							<h3 class="wtw_3dsitename"><div class='wtw_pricediv'>only <span class='wtw_price'>$35.<sup class='wtw_price'>00</sup></span> U.S. per month<br /><div class='wtw_floatright'>billed yearly</div></div>
								<?php _e( "<span class='wtw_bolder'>Business Service Plan</span> <span class='wtw_black'>for Your 3D Store</span>", 'walktheweb' ); ?></h3>
							<div class="wtw_clear"></div>
							<div class="wtw_black wtw_indent2 wtw_larger wtw_bolder"><?php _e( 'Service and Support Plan Includes', 'walktheweb' ); ?></div><br />
							<div class="wtw_black wtw_indent3"><strong>• <?php _e( "Personalize your 3D Store by using your own Domain Name!", 'walktheweb' ); ?></strong> <?php _e( 'Example', 'walktheweb' ); ?>: <strong>https://3d.</strong>YourDomain.com</div><br />
							<div class="wtw_black wtw_indent3"><strong>• <?php _e( "Secure your 3D Store with a Secure SSL Certificate", 'walktheweb' ); ?></strong> (<?php _e( 'Included', 'walktheweb' ); ?>).</div><br />
							<div class="wtw_black wtw_indent3"><strong>• <?php _e( "Protect your 3D Store with our Business Service Plan.", 'walktheweb' ); ?></strong></div><br />
							<div class="wtw_black wtw_indent3"><strong>• <?php _e( "Support your 3D Store with full Support - Respond within 12 hours.", 'walktheweb' ); ?></strong>.</div><br /><br />
							<div class="wtw_black wtw_center wtw_larger wtw_bolder"><span class='wtw_largest'>http<span class='wtw_blue'>s</span>://3d.<span class='wtw_blue'>YourDomainName.com</span></span></div><br />
							<div class="wtw_clear"></div>
							<div class="wtw_confirmlabel wtw_indent2"><?php _e( 'Your Domain Name', 'walktheweb' ); ?></div>
							<div class="wtw_inline">
								<div class='wtw_http3dcustom'>https://3d.</div><input type="text" id="walktheweb_siteurl3" name="walktheweb_siteurl3" class='wtw_customdomain' value="<?php echo esc_attr($domain); ?>" size="25" maxlength="256" /><br />
							</div>
							<div class="wtw_clear"></div><br />
							<div class="wtw_confirmlabel wtw_indent2"><?php _e( '3D Community to display', 'walktheweb' ); ?></div>
							<div class="wtw_inline">
								<select id="wtw_customdomaincommunityid2"></select>
							</div><br /><br />
							<div class="wtw_center">
								<input type="button" id="wtw_baddtocartbusiness" value="<?php _e( 'View Purchase Options', 'walktheweb' ); ?>" onclick="wtw.addToCart('2');" class="wtw_buttonaddtocart" />
								<div class="wtw_clear"></div><br />
								<div class="wtw_black"><?php _e( 'Note: Multiple Domain Names can be set to display the same 3D Community Website.', 'walktheweb' ); ?></div><br />
								<div class='wtw_black'><strong>http://3d.</strong> or <strong>https://3d.</strong> are trademarks that show it is a <strong>HTTP3D Inc. 3D Browsing</strong> website.<br /></div><br />
								<div class='wtw_black'><a href="https://www.walktheweb.com/wiki/custom-domain-name-dns-setup/" target="_blank"><?php _e( 'Here is how to set the DNS settings to make it work.', 'walktheweb' ); ?></a></div><br />
							</div>
						</div><br /><br />				
						<div class="wtw_roundpageoptional">
							<h3 class="wtw_3dsitename"><div class='wtw_pricediv'>only <span class='wtw_price'>$55.<sup class='wtw_price'>00</sup></span> U.S. per month<br /><div class='wtw_floatright'>billed yearly</div></div>
								<?php _e( "<span class='wtw_bolder'>Business Plus Service Plan</span> <span class='wtw_black'>for Your 3D Store</span>", 'walktheweb' ); ?></h3>
							<div class="wtw_clear"></div>
							<div class="wtw_black wtw_indent2 wtw_larger wtw_bolder"><?php _e( 'Service and Support Plan Includes', 'walktheweb' ); ?></div><br />
							<div class="wtw_black wtw_indent3"><strong>• <?php _e( "Personalize your 3D Store by using your own Domain Name!", 'walktheweb' ); ?></strong> <?php _e( 'Example', 'walktheweb' ); ?>: <strong>https://3d.</strong>YourDomain.com</div><br />
							<div class="wtw_black wtw_indent3"><strong>• <?php _e( "Secure your 3D Store with a Secure SSL Certificate", 'walktheweb' ); ?></strong> (<?php _e( 'Included', 'walktheweb' ); ?>).</div><br />
							<div class="wtw_black wtw_indent3"><strong>• <?php _e( "Protect your 3D Store with our Business Plus Service Plan.", 'walktheweb' ); ?></strong></div><br />
							<div class="wtw_black wtw_indent3"><strong>• <?php _e( "Support your 3D Store with full Support - Respond within 4 hours.", 'walktheweb' ); ?></strong>.</div><br /><br />
							<div class="wtw_black wtw_center wtw_larger wtw_bolder"><span class='wtw_largest'>http<span class='wtw_blue'>s</span>://3d.<span class='wtw_blue'>YourDomainName.com</span></span></div><br />
							<div class="wtw_clear"></div>
							<div class="wtw_confirmlabel wtw_indent2"><?php _e( 'Your Domain Name', 'walktheweb' ); ?></div>
							<div class="wtw_inline">
								<div class='wtw_http3dcustom'>https://3d.</div><input type="text" id="walktheweb_siteurl4" name="walktheweb_siteurl4" class='wtw_customdomain' value="<?php echo esc_attr($domain); ?>" size="25" maxlength="256" /><br />
							</div>
							<div class="wtw_clear"></div><br />
							<div class="wtw_confirmlabel wtw_indent2"><?php _e( '3D Community to display', 'walktheweb' ); ?></div>
							<div class="wtw_inline">
								<select id="wtw_customdomaincommunityid3"></select>
							</div><br /><br />
							<div class="wtw_center">
								<input type="button" id="wtw_baddtocartbusinessplus" value="<?php _e( 'View Purchase Options', 'walktheweb' ); ?>" onclick="wtw.addToCart('3');" class="wtw_buttonaddtocart" />
								<div class="wtw_clear"></div><br />
								<div class="wtw_black"><?php _e( 'Note: Multiple Domain Names can be set to display the same 3D Community Website.', 'walktheweb' ); ?></div><br />
								<div class='wtw_black'><strong>http://3d.</strong> or <strong>https://3d.</strong> are trademarks that show it is a <strong>HTTP3D Inc. 3D Browsing</strong> website.<br /></div><br />
								<div class='wtw_black'><a href="https://www.walktheweb.com/wiki/custom-domain-name-dns-setup/" target="_blank"><?php _e( 'Here is how to set the DNS settings to make it work.', 'walktheweb' ); ?></a></div><br />
							</div>
						</div><br /><br />
					</div>
				</div>		
			</div>			
			<div id="wtw_siteform8" class="wtw_widehidden">
				<img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer18" class="wtw_spacer" />
				<div class="wtw_wide"><img src="<?php echo WTW_PLUGIN_URL; ?>/assets/images/hidden.png" id="wtw_ispacer19" class="wtw_spacer" />
					<div class="wtw_roundpage">
						<a href="https://3d.walktheweb.com" target="_blank"><img id="wtw_iwtwsplash" src="<?php echo esc_url(site_url()); ?>/wp-content/plugins/walktheweb/assets/images/bluering3dbrowsing.png" class="wtw_productimage" /></a><br />
						<div class='wtw_black wtw_floatleft wtw_indent2'>
							<div class='wtw_larger wtw_bold'>HTTP3D Inc. - <span class="wtw_wtwblue">Walk the Web<sup>®</sup></span></div>
							1050 Rosecrans St. Ste. L<br />
							San Diego, CA 92106<br />
							<a href="https://www.walktheweb.com" target="_blank">https://www.walktheweb.com</a>
						</div>
						<div class='wtw_black wtw_floatright wtw_indentright2'>
							<div class='wtw_larger wtw_bold'><?php _e( 'Contact Us', 'walktheweb' ); ?></div>
							(WAL)KTH-EWEB<br />
							(925) 584-3932<br />
							<a href="mailto:PluginSupport@WalkTheWeb.com">PluginSupport@WalkTheWeb.com</a>
						</div>
						<div class="wtw_clear"></div><br />
					</div><br /><br />
					<h3 class="wtw_searchheader"><span class="wtw_wtwyellow">Walk the Web<sup>®</sup></span> - WordPress Plugin <?php _e( 'Help', 'walktheweb' ); ?></h3>
					<div class="wtw_roundpage">
						<div id="wtw_loadingwphelp" class="wtw_loading">- - - - - <?php _e( 'Loading', 'walktheweb' ); ?> - - - - -</div>
						<div id="wtw_wphelplist"></div>
					</div><br /><br />
					<h3 class="wtw_searchheader"><span class="wtw_wtwyellow">Walk the Web<sup>®</sup></span> - <?php _e( '3D Website Help', 'walktheweb' ); ?></h3>
					<div class="wtw_roundpage">
						<div id="wtw_loadinghelp" class="wtw_loading">- - - - - <?php _e( 'Loading', 'walktheweb' ); ?> - - - - -</div>
						<div id="wtw_helplist"></div>
					</div><br /><br />
				</div>		
			</div>	
			<div id="wtw_submitform" class="wtw_hidden">	
				<?php submit_button(); ?>
			</div>
			<div class="wtw_roundpagefooter">
				<strong>3D Browsing</strong> is patented by <a href="mailto:adishno@walktheweb.com">Dr. Aaron Dishno</a> at HTTP3D Inc. - <span class="wtw_wtwBlue">Walk the Web<sup>®</sup></span><br />
				<strong>HTTPS://3D</strong>, <strong>HTTP://3D</strong>, <strong>HTTP3D</strong>, and <strong>Walk the Web</strong> are Trademarks of <strong>HTTP3D Inc.</strong> All Rights Reserved.<br />
				Read more about <strong>3D Browsing</strong> at <a href="https://www.walktheweb.com" target="_blank">https://www.walktheweb.com</a>.
			</div>
		</div>
	</form>
	</div>
	<?php
		}
	}	
}
?>